
package org.demo.env;

import org.objectweb.telosys.auth.IUserValidator;
import org.objectweb.telosys.common.IApplicationLogger;
import org.objectweb.telosys.common.IExternalMainFactory;
import org.objectweb.telosys.common.TelosysObject;
import org.objectweb.telosys.rpl.xml.IXmlWrapperProvider;
import org.objectweb.telosys.screen.core.IScreenDataProvider;
import org.objectweb.telosys.screen.core.IScreenProvider;
import org.objectweb.telosys.service.IServiceProvider;

/**
 * Main application factory<br>
 * 
 * This factory is designed to provide the application implementations
 * of services needed by the Telosys framework.
 *  
 */
public class MainFactory extends TelosysObject implements IExternalMainFactory
{
    private static ScreenRegistry     $screenRegistry     = null;

    private static ServiceRegistry    $serviceRegistry    = null;

    // Useless since v 1.0
    //private static XmlMapperRegistry  $xmlWrapperRegistry = null;

    /**
     *  
     */
    public MainFactory()
    {
        super();
        info("MainFactory creation ...");
        //--- Initialize the Screen Registry if necessary
        if ($screenRegistry == null)
        {
            info("screen registry creation ...");
            $screenRegistry = new ScreenRegistry();
        }
        //--- Initialize the Service Registry if necessary
        if ($serviceRegistry == null)
        {
            info("service registry creation ...");
            $serviceRegistry = new ServiceRegistry();
        }
        
        //--- Initialize the XML Mapper Registry if necessary
        /* can be null since v 1.0
        if ($xmlWrapperRegistry == null)
        {
            info("xml wrapper registry creation ...");
            $xmlWrapperRegistry = new XmlMapperRegistry();
        }
        */
    }

    public IXmlWrapperProvider getXmlWrapperProvider()
    {
        trace("getXmlWrapperProvider()");
        //return $xmlWrapperRegistry;
        // Since v 1.0 the XmlWrapperProvider is optional 
        // if null => dynamic XML Mapper Registry managed by the framework
        return null ; // v 1.0.0
    }

    public IScreenDataProvider getScreenDataProvider()
    {
        trace("getScreenDataProvider()");
        return $screenRegistry;
    }

    public IScreenProvider getScreenProvider()
    {
        trace("getScreenProvider()");
        return $screenRegistry;
    }

    public IServiceProvider getServiceProvider()
    {
        trace("getServiceProvider()");
        return $serviceRegistry;
    }

    public IUserValidator getUserValidator()
    {
        trace("getUserValidator()");
        return new UserValidator();
    }


    /* (non-Javadoc)
     * @see org.objectweb.telosys.common.IExternalMainFactory#getApplicationLogger()
     */
    public IApplicationLogger getApplicationLogger()
    {
        trace("getApplicationLogger()");
        return null ; // No logger
        //return new FrameworkLoggerLog4J() ; // Log4J logger
    }

}