package org.demo.env;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;

import org.objectweb.telosys.auth.IAppUser;
import org.objectweb.telosys.auth.IUserValidator;
import org.objectweb.telosys.common.TelosysException;
import org.objectweb.telosys.common.TelosysObject;
import org.objectweb.telosys.dal.sql.ConnectionManager;


/**
 * User Validator class example
 *
 */
public class UserValidator extends TelosysObject implements IUserValidator
{
	/**
	 * @see org.telosys.demo.auth.IUserValidator#validUser(java.lang.String, java.lang.String)
	 */
	public final IAppUser validUser(final String sLogin, final String sPassword)
	{
	    info("validUser("+sLogin+",***)");
		// return checkUserSql (sLogin, sPassword);
		return checkUserPasswordOK (sLogin, sPassword);
	}
	/**
	 * For tests only !
	 * User authenticated if password is "OK"
	 * If authenticated, a dummy user is created and returned  
	 * @param sInputLogin
	 * @param sInputPassword
	 * @return
	 */
	private static User checkUserPasswordOK(final String sInputLogin, final String sInputPassword)
	{
		User user = null;
		if ( sInputPassword.equalsIgnoreCase("ok") )
		{
		    user = new User(sInputLogin, "Toto", User.PROFILE_STANDARD);
		}
		return user ;
	}
	
	/**
	 * Checks user/password using the database
	 * @param sInputLogin : user login
	 * @param sInputPassword : user password
	 * @return : user object if "login/password" OK, else null
	 */
	public static User checkUserSql(final String sInputLogin, final String sInputPassword)
	{
		User user = null;
		String sSql = null;
		Connection con = null;
		PreparedStatement ps = null;
		try
		{
			//--- Connexion SGBD
			con = ConnectionManager.getConnection(); // Default DataBase
			//--- Controle d'existence
			sSql = "select NAME, PROFILE, PASSWORD from APPUSER where LOGIN = ? ";
			ps = con.prepareStatement(sSql);
			ps.setString(1, sInputLogin);
			ResultSet rs = ps.executeQuery();
			if (rs.next())
			{
				//--- Le login existe
				String sNom = rs.getString(1);
				int iProfile = rs.getInt(2);
				String sPassword = rs.getString(3);
				if (sInputPassword.equals(sPassword))
				{
					//--- Le mot de passe est correct
					user = new User(sInputLogin, sNom, iProfile);
				}
			}
			rs.close();
			ps.close();
			//--- Fin normale de traitement
		}
		catch (SQLException ex)
		{
			user = null;
		}
		catch (TelosysException ex)
		{
			user = null;
		}
		finally
		{
			try
			{
				if (ps != null)
				{
					ps.close();
				}
				if (con != null)
				{
					con.close();
				}
			}
			catch (SQLException ex)
			{
				user = null;
			}
		}
		return user;
	}

}